#
# spec file for package libwacom
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

# library version from upstream meson.build
%define sover 9

Name:           libwacom
Version:        2.15.0
Release:        1.1
Summary:        Tablet description library
License:        HPND
Group:          Development/Libraries/C and C++
URL:            https://linuxwacom.github.io/
Source0:        https://github.com/linuxwacom/libwacom/releases/download/libwacom-%{version}/libwacom-%{version}.tar.xz
Source1:        https://github.com/linuxwacom/libwacom/releases/download/libwacom-%{version}/libwacom-%{version}.tar.xz.sig
# Fetched from https://github.com/whot.gpg
Source2:        %{name}.keyring
Source99:       baselibs.conf
BuildRequires:  meson >= 0.57.0
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(libevdev) >= 1.7.0
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  doxygen

%description
libwacom is a library to identify graphics tablets and their model-specific
features. It provides access to information such as "is this a built-in
on-screen tablet", "what is the size of this model", etc.

%package -n libwacom%{sover}
Summary:        Library to identify wacom tablets
Group:          System/Libraries
Requires:       %{name}-data >= %{version}

%description -n libwacom%{sover}
libwacom is a library to identify graphics tablets and their model-specific
features. It provides easy access to information such as "is this a built-in
on-screen tablet", "what is the size of this model", etc. The name libwacom is
historical — it was originally developed for Wacom devices only but now
supports any graphics tablet from any vendor.

%package data
Summary:        Data files for libwacom, a table identification library
Group:          System/Libraries

%description data
libwacom is a library to identify graphics tablets and their model-specific
features. It provides access to information such as "is this a built-in
on-screen tablet", "what is the size of this model", etc.

%package tools
Summary:        Command-line tools for libwacom
Group:          Hardware/Other
Requires:       python3-libevdev
Requires:       python3-pyudev

%description tools
libwacom is a library to identify graphics tablets and their model-specific
features.
This subpackage provides command-line utilities to query/update the database.

%package devel
Summary:        Header files for libwacom
Group:          Development/Libraries/C and C++
Requires:       libwacom%{sover} = %{version}

%description devel
libwacom is a library to identify graphics tablets and their model-specific
features.
This subpackage provides the header files for the library.

%prep
%autosetup -p1

%build
%meson -Db_lto=true -Dtests=disabled
%meson_build

%install
%meson_install

sed -e 's-#!/usr/bin/env python3-#!/usr/bin/python3-g' -i %{buildroot}%{_bindir}/*
find %{buildroot} -type f -name "*.la" -delete -print
%python3_fix_shebang

%check
%meson_test

%ldconfig_scriptlets -n libwacom%{sover}

%files -n libwacom%{sover}
%license COPYING
%doc NEWS README.md
%{_libdir}/libwacom.so.%{sover}*

%files data
%license COPYING
%dir %{_datadir}/libwacom
%{_datadir}/libwacom/*.tablet
%{_datadir}/libwacom/*.stylus
%{_datadir}/libwacom/layouts/
%dir %{_udevrulesdir}
%{_udevrulesdir}/65-libwacom.rules
%dir %{_udevhwdbdir}
%{_udevhwdbdir}/65-libwacom.hwdb

%files tools
%license COPYING
%{_bindir}/libwacom-list-devices
%{_bindir}/libwacom-update-db
%{_bindir}/libwacom-show-stylus
%{_bindir}/libwacom-list-local-devices
%{_mandir}/man1/libwacom-list-devices.1%{?ext_man}
%{_mandir}/man1/libwacom-list-local-devices.1%{?ext_man}
%{_mandir}/man1/libwacom-show-stylus.1%{?ext_man}

%files devel
%license COPYING
%{_includedir}/libwacom-1.0/
%{_libdir}/*.so
%{_libdir}/pkgconfig/libwacom.pc

%changelog
* Sat Mar 22 2025 Aesara Binder <aesara@mailbox.org>
- update to 2.15.0
  * New devices:
  - Still more tablet definitions (#841)
  - add XP Pen Innovator 16 definition & layout
  - Support for XP-Pen Deco Pro S
  - Add Lenovo Slim Pen
  - Add the XP Pen Deco01 v3
  - Add 3rd gen Intuos Pro devices
  * Device fixes:
  - fix duplicate button listing for the DTI-520
  - Remove duplicate of the ISDv4 2d1f 0040 tablet
  * Device other:
  - Add AliasOf keyword to wacom.stylus
  - prefix all styli with a vendor ID
  - prefix the wacom 2d1f ISDv4 devices with wacom
  - Allow for a bustype of 0 on real devices
  - Add support for getting the target mode for a modeswitch button
* Sun Feb 23 2025 Aesara Binder <aesara@mailbox.org>
- update to 2.14.0
  * Extended Lenovo Yoga X1 Gen5 support, improved the Huion mini
    keydial (KD100)
  * Fixed missing Strip in the Huion Kamvas Pro 16
  * Corrected entry for Elan 5515
  * Fixed outdated properties for Lenovo Yoga 9 14IAP7
  * Add support for Dial status LEDs
  * .tablet files shadow any ones with the same name
  * New XP Pen devices supported: Artist 22R Pro, 24 Pro, Deco Fun
    L, ACK05 Remote, Pro Pen 3E
  * New Lenovo device ssupported: Yoga 9 14IAP7, Active Pen 3
    (2023), Digital Pen 2, X1 Fold 16 Gen1, Precision Pen 2 (2023)
    stylus
  * New ELAN devices supported: ELAN-2514 variant 04f3:2f9d, ELAN
    9008 and 9009 (Asus Zenbook Duo UX8406MA 1200p), ELAN 2F2A and
    41A1 (ZenBook Pro Duo UX8402VV)
  * New Wacom devices supported: HID 5214 (IdeaPad Flex 5 14ARE05
    rev.81X2), HID 52C6 Pen.
  * New HP devices supported: Spectre x360, Elite Chromebook C1030
  * Other devices supported: StarLite Mk V; HP Spectre x360
    13-aw0020ng; Huion RTP-700, Huion KeyDial K20
  * Database: support $XDG_CONFIG_HOME/libwacom as additional path
  * tools/clean_svg: allow passing in a .tablet file
  * tools/list-local-devices: print the vid/pid if available
  * tools/debug-device: print the device class too
* Fri Aug 16 2024 Aesara Binder <aesara@mailbox.org>
- update to 2.12.2
  * Device Fixes:
  - HUION Kamvas 16 2019
  - Prefix the kamvas pro 13 with Huion like all other Huion
    tablets
  - Fix the Huion Kamvas 12 file
  * Device Other:
  - Don't create a default match for fallback devices
  * Other Fixes:
  - Fix a memory leak
  - Set the device name in new_from_path() to override the
    fallback name
  * Tests:
  - test: run ruff format over test_svg.py
  - test: add support for testing new_from_path() through uinput
- update to 2.12.1
  * Device Fixes:
  - Drop the firmware match from the Huion Inspiroy 2 S
  * Features:
  - Fix off-by-one check for stripping the quote from NAME/UNIQ
  - Use g_clear_pointer() during libwacom_*_unref()
- update to 2.12.0
  * New Devices:
  - Huion Kamvas Pro 24 (GT-240, QHD)
  - Huion WH1409
  - Wacom Movink
  - Wacom HID 49A0 (Dell latitude 5320 2-in-1)
  - Wacom HID 5334 Pen
  - XP-PEN Deco Mini 4
  * Device Fixes:
  - Fix tablet file for the Huion Inspiroy 2S
  - Improve Huion Inspiroy 2 m support
  - Update the Inspiroy 2L
  - Add a dial to the Huion Inspiroy 2 L and M
  - Fix the Inspiroy 2S layout
  - Set the right PID for the Inpspiroy 2 L and M
  - Rename second ButtonB id in the DTI-520 svg layout
  - Fix Huion RTM-500 Support
  - Added more device names for Kamvas 13 variants
  - Fix buttons for Huion and Gaomon tablets
  - Mark huion/gaomon tablets with Dials as such
  - XP pen tablets have no Rings
  - Drop accidental comma from the Gaomon/Huion layout files
  * Device Other:
  - Auto generated HUION tablet description files
  - Auto generated GAOMON tablet description files
  - Remove layout files without buttons/strips/dials
  - Remove a superfluous rect from the huion mini keydial kd100
  - Use NumRings instead of separate Ring/Ring2
  - Switch DeviceMatch to use a pipe as separator
  - Add a firmware string entry to the matches
  - Skip over empty Layout= assignments
  * Features:
  - Rework match_from_string
  - Rework the match approach to prefer uniq over name
  - Allow to match by uniq without name
  - Add Gaomon S620 firmware match
  - Add support for relative dials
  - Add libwacom_new_from_builder to construct a new device
  * Other Fixes:
  - Fetch the name and uniq from udev properties, not sysfs
  - Keyboard devices are not ID_INPUT_TABLET_PAD
  - Don't mark a Mouse device as tablet or pad
  - Set the bustype in libwacom_new_for_path
  - Document touch strips
  * Tests:
  - Remove the requirement for a Layout file
  - Replace the SVG validity test with a pytest-based one
  - Add a test for unnecessary SVGs
  - Add some tracing to the svg validity test
  - Svgs for dials need to have CW and CCW labels, not Up/Down
  - Set proper test names for the hwdb tests
  - Skip errors in SVGs for autogenerated devices
  - Check the svg for Dial2 if we have two dials
  - Skip hwdb tests if the systemd commands fail
  - Install our hwdb file during the test
  - Add ids to the parametrized tablet file tests
  - Add a pytest wrapper for libwacom
  - Skip/fail with an error if the systemd commands failed
  - Replace the uinput-based hwdb test with a direct query
  - Don't reload the udev rules
  - Move the asan check into meson.build
  * Build:
  - Make pytest more verbose
  - Bump to meson 0.56.0
  - More logging of the pytests
  - Split the pytest invocations into separate ones
* Mon Apr 22 2024 Dirk Müller <dmueller@suse.com>
- update to 2.11.0:
  * New Devices:
  - Asus Zenbook Duo
  - Lenovo Ideapad Duet, Ideapad Duet 3, Thinkpad L13 Yoga
    Gen 3
  - HP Envy x360
  * The default fallback device is now an integrated tablet
* Tue Mar 26 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang macro, [bsc#1212476]
* Thu Mar  7 2024 Aeneas Jaißle <aj@ajaissle.de>
- update to 2.10.0:
  * Append to DeviceMatch for X1 Yoga Gen 5 (#632)
  * Add .tablet file for Ingenic touch and pen display (#621)
  * Update the name for the Dell Active Pen (#628)
  * Add support for xp-pen artist 10s table (#625)
  * github: Minimize permissions granted to automated
    workflows / jobs
  * data: Update ModelName for DTH134 and DTC121
  * data: Add Wacom HID-5362
  * github: update the issue templates
  * github: add a label commenter bot
  * Add an editorconfig file
  * github: fix the sysinfo check workflow
  * tools: fix a memleak in list-local-devices
  * Fix an indentation issue
  * data: Intuos Pro 2 is compatible with Intuos 4 styli
  * libwacom 2.10.0
  * data: add isdv4-50a0 (#630)
  * build(deps): bump tj-actions/changed-files in
    /.github/workflows
  * Add support for Lenovo ThinkPad X1 Yoga Gen 7 (#626)
- update to 2.9.0:
  * data: add Wacom Cintiq Pro 22 & 17
  * data: remove erroneous dash from latest Cintiq Pro model
    names
  * data: add dtc121
  * data: add dth134
  * meson.build: correct license to HPND
  * Switch strcmp to g_str_equal()
  * meson.build: remove duplicate pytest run
  * Add support for evdev code parsing
  * Drop the separate Button= assignment
  * database: move parsing the features into a helper
  * data: add a new Keys/KeyCodes entry to the tablet files
  * CI: fix the pages job for the new libevdev dependency
  * libwacom: only memcmp the led data if we have leds
  * libwacom 2.9.0
  * data: Add isdv-48b7 (#604)
  * Add data for XP-Pen G430s (#603)
  * data: Add XP-Pen Artist 13.3 Pro (#601)
- requires libevdev >= 1.7.0
* Mon Sep 11 2023 Dirk Müller <dmueller@suse.com>
- update to 2.8.0 (bsc#1214390):
  * data: Add "Wacom One pen tablet"
  * data: add Wacom One 12 & Wacom One 13
  * data: Add support for the Samsung Chromebook Plus v2
  * data: Add support for Nuvision Solo 10 Draw
  * data: add ELAN 2C1B and 2D55 (Asus ZenBook Pro Duo UX482EG)
  * data: create a stylus group for the generic-no-eraser pen
  * data: create a generic-with-eraser group for the default
    stylus
  * data: include another device name for the Huion H950P
  * libwacom 2.8.0
  * data: add XP Pen Deco mini7
- update keyring with keys from https://github.com/whot.gpg
* Mon May 29 2023 Dirk Müller <dmueller@suse.com>
- update to 2.7.0:
  * Added support for XP-Pen Deco MW (#548)
  * Add support for Lenovo Ideapad Duet 5i
  * Add support for HP Spectre x360 14
  * data: make XP-Pen Deco Pro MW layout generic
  * data: Add XP-Pen Deco Pro SW
  * Format python files with Python black
  * tools: add list-local-devices as builddir tool
  * data: narrow down the Huion H950p to include a name match
  * tools: list the kernel name together with the event node
  * Add ID 04f3:23b9 for HP Envy x360 ar0xxx (#550)
  * Add Wacom HID 52D3 (Lenovo Yoga 7 14ARB7)
  * Update to follow auto-generated standard
  * Add Wacom HID 52D5 (Lenovo Yoga 7 14ARB7) (#549)
  * Support for xp-pen deco pro mw (#552)
* Sat Feb  4 2023 Dirk Müller <dmueller@suse.com>
- update to libwacom-2.6.0:
  * Add Ugee M708 v1 tablet
  * Add tablet definition for Wacom HID 52FA Pen (#536)
  * Added support for XP-Pen Deco01 v2
  * tools/clean_svg: don't modify the dict while iterating
  * data: add the sysinfo to the wacom.example file
  * CI: update some actions to newer versions
  * CI: bump an action to the current version
  * README: note that we support tablets other than Wacom's
    too
  * CI: bump to use latest Ubuntu LTS
  * Add tablet definition for Huion Kamvas 13
  * tests: fix failure if system doesn't use systemd
* Mon Jan 16 2023 Dirk Müller <dmueller@suse.com>
- update to 2.5.0:
  - Cintiq Pro 27
  - Intuos Pro Small refresh
  - Dell Chromebook 11 5190 2-in-1
  - Dell Inspiron 14 7425 2-in-1
  - Fujitsu U729X
- update keyring
* Thu Jul 28 2022 Dirk Müller <dmueller@suse.com>
- update to 2.4.0:
  - Huion Inspiroy H1060P
  - XP-Pen Artist 12, Deco L
  - Chuwi MiniBook X
  - Acer Chromebook Spin 13
  - Huion HS611
  - Lenovo 14s Yoga, X13 Yoga, X1 Yoga, X380
  - Samsung Galaxy Book Pro 360, Flex2
- Devices matching a "* Keyboard" glob are no longer treated as tablets
* Thu Jun  2 2022 Michal Suchanek <msuchanek@suse.com>
- Remove meson conditional - no other build system is supported.
* Sun May 29 2022 Dirk Müller <dmueller@suse.com>
- update to 2.2.0:
  * data: Add ISDv4 5285 (Lenovo ThinkPad X13 Yoga Gen 2)
  * data: Add ISDv4 16C (HP ZBook x2 G4)
  * Add ISDv4 52a2 (Lenovo Yoga 6 13ALC6)
  * data: Add ISDv4 5218 (Lenovo IdeaPad Flex 5 14ALC05)
  * data: Add ISDv4 521c (Lenovo IdeaPad Flex 5 15ALC05)
  * data: Add ISDv4 49a3 (Dell Latitude 7320 Detachable)
  * Remove now-unused libwacom.pc.in
  * CI: add a workflow to check for "sysinfo" in newly added data files
  * doc: fix the check for integration flags in the example code
  * github: bump freebsd workflow to 0.1.5
  * Update data/surface-go-2.tablet
  * Update huion-h610-pro.tablet
  * data: Add ISDv4 4995 (HP EliteBook x360 1040 G8 Notebook PC)
  * data: Add ISDv4 51EF (Lenovo Yoga C740-14IML)
  * data: Add ISDv4 2d1f:0095 (PINE64 PineNote)
  * data: Add ISDv4 52b0 (Lenovo Yoga 7 14ACN6)
  * data: Add ISDv4 511a (Lenovo ThinkPad X1 Tablet Gen 3)
  * data: Add ISDv4 484d (Dell Latitude 5290)
  * Add description for elan-2a70 (#466)
  * data: remove unknown BuiltIn key from the DTU1931
  * data: Add ISDv4 5276 (Lenovo ThinkPad X1 Yoga Gen 6)
  * data: Add ISDv4 51d0 ("Lenovo ThinkPad X1 Titanium Gen 1")
  * data: Add ISDv4 5019 (Fujitsu LIFEBOOK T935)
  * test: add a test for matching the button count with the evdev codes
  * meson.build: use gnu_symbol_visibility argument
  * meson.build: use current_source_dir() over deprecated source_root()
  * Remove unused arguments from two helper functions
  * github: build with ninja --verbose
  * CI: don't enable -Wall -Wextra in the CI
  * Make sign-compare a warning/error
  * Add support for a new "Wacom One Pen Display 13"
* Fri Nov 19 2021 Callum Farmer <gmbr3@opensuse.org>
- Add python requires to tools subpackage (bsc#1192852)
* Tue Nov  2 2021 Callum Farmer <gmbr3@opensuse.org>
- update to 1.12:
  - New devices:
  - ELAN 2513
  - HP Probook x360, 435 G7
  - Waltop Slim Tablet 12.1
  - XP-PEN Star 3
  - Lenovo ThinkPad L390 Yoga, Yoga C940, Yoga 460, Yoga 720
  - ThinkVision M14t, IdeaPad Flex5
  - HP EliteBook x360 1030 G3
  - Dell XPS 13 9310 2-in-1
  - HUION Kamvas Pro 13
  - ELAN 2514 variant 2718
  - libwacom's hwdb no longer tags devices with "Keyboard" in
    their name as ID_INPUT_TABLET
* Sat May  8 2021 Dirk Müller <dmueller@suse.com>
- update to 1.10:
  - Duplicate matches in /etc no longer cause conflicts with the
    system-provided .tablet files
  - libwacom-list-local-devices now prints YAML by default
  - New tools:
  - libwacom-list-devices lists all supported devices
  - libwacom-update-db to update the db after adding tablet files
  - New devices:
  - Elan 2514 variant 25BF
  - Huion H640P
  - Lenovo X1 Yoga Gen 6
  - Samsung CHromebook Pro
  - libwacom can now read tablet and stylus files from /etc/libwacom
  - New tool: libwacom-show-stylus to interactively show stylus IDs and serial
    numbers
  - New devices:
  - HP Envy x360, Pro Tablet 508
  - Lenovo X1 Yoga Gen5, Yoga6, Ideapad Flex 5, Yoga 7, Yoga C650, L13 Yoga
  - Microsoft Surface Go
  - New devices:
  - Dell XPS 15 7590
  - HP EliteBook x360 (830 and 1030), Spectre x360
  - Lenovo Thinkpad P15 Gen1, Yoga, Yoga 3, Yoga 11e, X13 Yoga
  - New devices:
  - Dell XPS 13 2-in-1 9310
  - Lenovo IdeaPad Flex 14API, Flex 5
  - HP Envy x360, EliteBook x360
  - Huawei MateBook HZ-W19
  - XP Pen Star G640
* Mon Nov  9 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.6:
  * add XP Pen G640
  * add XP Pen G430
  * build fixes
* Mon Oct  5 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Use official %%%%meson_test macro for the %%check section.
- Do not crrate empty %%check section when not using meson.
* Mon Oct  5 2020 Michal Suchanek <msuchanek@suse.com>
- Fix Leap build.
* Sun Sep 13 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.5:
  - New devices:
  - Acer Spin 5 / Acer Spin SP513-54N
  - Dell Latitude 7410,
  - GAOMON S620
  - HP Pavilion x360 Convertible 14-dh0xxx
  - Huawei MateBook HZ-W19
  - Lenovo ThinkPad X1 Yoga 3rd
  - Wacom Cintiq 16, DTK-1660E
* Sat Aug 22 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.4.1:
- New devices:
  - HP ZBook Studio x360 G5
  - Dell Latitude 7285
  - Dell Latitude 7200 2-in-1, Dell Latitude 7400 2-in-1
  - Elan 2415
  - HP ENVY x360 Convertible 13,
  - Huion 420, 1060 Plus,
  - GAOMON S56K
  - Wacom FT-0405
  - Many AES stylus definitions added
  - New API: libwacom_stylus_get_eraser_type()
  - udev rules are now using hwdb entries
* Thu May  7 2020 pgajdos@suse.com
- use %%{_udevrulesdir}, %%{_libexecdir} now expands to /usr/libexec
* Thu Mar 26 2020 Stasiek Michalski <stasiek@michalski.cc>
- Update to 1.3
- Add a dependency on doxygen
- Remove 174.patch
  + The changes were merged upstream
* Wed Nov 20 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Pass b_lto option to meson, otherwise the previous patch has no
  effect (meson does not derive the b_lto value from the FLAGS).
* Wed Nov 20 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Add 174.patch
  (https://patch-diff.githubusercontent.com/raw/linuxwacom/libwacom/pull/174.patch):
  + Disable deprecated symbol test when using LTO.
* Thu Nov 14 2019 Michael Gorse <mgorse@suse.com>
- Update to 1.1:
  New devices: Wacom HID 5115
  Other change:
  * Button codes defined for the 3rd gen Intuos S
  Changes from version 1.0:
  - udev rules are now installed by default
  Changes from version 0.99.901:
  New devices
  * Lenovo YOGA 720, YOGA 520, IdeaPad FLEX 5, MIIX 520
  * Dell XPS 15 9570, Latitude 5175
  * HP Spectre x360, Envy x360 Convertible
  * Wacom Intuos Pro 2 S, Cintiq 22, DTK-1660E
  * Huion 610 Pro v2
  * Samsung 930QAA
  Other changes:
  * New API: libwacom_get_model_name()
  * meson build system support
  * fixed symbol versioning
  * EKR button ordering fixed
  * Stylus grouping added
  Changes from version 0.33:
  - New devices:
  * Wacom Bamboo Fun 4x5, Bamboo Fun 6x8, Bamboo1 5x8, Cintiq 16
  * HP EliteBook x360, x2, HP Envy x360
  * Acer Switch SA5
  * Huion H420
  * Lenovo Thinkpad L380 Yoga, L390 Yoga, Ideapad Flex, Yoga 730
  * Dell Latitude 7390
- Switch to meson for 15.2/tumbleweed
- Remove URI from keyring: file is no longer there.
- Add libxml2 to BuildRequires.
- Don't manually install udev rules: now done by install.
- Switch URL to github.
* Tue Jan 29 2019 cornelis@solcon.nl
- Run through spec-cleaner
* Mon Jan 28 2019 Cor Blom <cornelis@solcon.nl>
- Update to 0.32
  Support for the following devices has been added:
  * Lenovo Yoga 730, X380, 300e
  * Dell XPS 15 9575
  * HP Spectre x360
  * Toshiba Portege X20W-D
  * DTU-1141B
  * Graphire4 6x8
  * ISDv4 50fd, 4807
  Other change:
  * tools: provide a man page for libwacom-list-local-devices
* Thu Jun  7 2018 astieger@suse.com
- update to 0.30 to support the following devices (boo#1096292):
  * Lenovo X1 Yoga 3rd
  * HP Spectre x360, HP Elite x1012 G2, HP Envy x360
  * Turcom TS-6610
  * ISDv4 50b4
  * Cintiq Pro 24, Cintiq Pro 32
  * ISDV4 5099, 50b6, 509d, 5090, 50f1, 50f8, 5110, 508b
  * Bamboo Pad
  * DTK-2451, 2452
  * One by Wacom (2nd gen)
  * Dell Canvas 27
  * Pro Pen 3D stylus
  * XP-Pen Star 03
  * ISDv4 4831 (Dell XPS 13 9365)
  * DTH-1152
  * Wireless Intuos Pro 2nd Generation
  * ISDV4 4809, 481a 4822, 4824, 484c, 5010
  * ISDV4 104, 10E, 117, 124, 4814, 5013, 5014, 503E, 503F, 5048, 5044
  * USB Graphire
  * Cintiq Pro 13, 16
  * Second generation Intuos Pro M
  * Second generation Intuos Pro L
- verify source signatures
* Fri Jun  2 2017 msuchanek@suse.com
- Build wacom udev rules (boo#1041714)
  fixes libinput error: libinput bug: Device 'Wacom BambooPT 2FG Small Pad'
  does not meet tablet criteria. Ignoring this device.
* Tue Jan 31 2017 adrien.plazas@suse.com
- Update to version 0.23
  + New devices:
  - ISDV4 5040, MobileStudio Pro
  + The 22HD(T) is now marked as having strip modes
- Changes from version 0.22
  + New API: libwacom_get_paired_device()
  + The EKR has the modes enabled now
  + Fixes to the show-svg-image tool
- Changes from version 0.21
  + New devices:
  - MTE-450 "Bamboo", Lenovo ThinkPad Tablet 10
  + Layout fixes for the Express Key Remote, Intuos series
- Changes from version 0.20
  + New devices: "One by wacom"
  + Layout fixes, especially for the Express Key Remote
- Changes from version 0.19
  + New devices:
  - DTK-1651, ISDv4 0x504a
  + Quirk added to prevent udev tagging HUION Consumer Control devices as
    tablets
- Changes from version 0.18
  + Renamed ".tablet" files for Bamboo devices
  + Modified user-visible names of Bamboo devices
  - "Wacom Bamboo 16FG 4x5" -> "Wacom Bamboo Capture"
  - "Wacom Bamboo 2FG 4x5" -> "Wacom Bamboo (2FG)"
  - "Wacom Bamboo 2FG 6x8" -> "Wacom Bamboo Fun medium (2FG)"
  - "Wacom Bamboo 2FG" -> "Wacom Bamboo Touch (2FG)"
  - "Wacom Bamboo Craft" -> "Wacom Bamboo Fun small (2FG)"
  - "Wacom Bamboo Pen" -> "Wacom Bamboo Pen small"
  + New devices:
  - Missing gen-1 Bamboo (0xd5)
  - Missing gen-2.5 Bamboos (0xd6, 0xd7, 0xd8, 0xd9, 0xda, 0xdb)
  - Missing gen-3 Bamboos (0xdc, 0xdd, 0dxf)
- Changes from version 0.17
  + New devices:
  - Cintiq Companion 2 (DTH-1310)
  - ExpressKey Remote
  + New WacomClass: WCLASS_REMOTE
- Changes from version 0.16
  + Data files for Intuos and Intuos 2 series added
  + New stylus ID 0x8e2
* Sun Aug 16 2015 p.drouand@gmail.com
- Update to version 0.15
  * Support added for ISDv4 0x4800 (Dell Venue 10 5050 Android tablet)
  * Bustype i2c is now supported
- Changes from version 0.14
  * Support added for Cintiq 13HD touch
  * Fixes to the udev rule set to tag uinput devices correctly too
  * Integrated tabled are not marked as ID_INPUT_TOUCHPAD anymore now
* Sat Apr 25 2015 zaitor@opensuse.org
- Update to version 0.13:
  + New devices:
  - DTU-1141.
  - Huion H610 Pro.
  + Several memory leak fixes.
  + Added libwacom_match_get_name() to allow data-file matching on
    the name as well as the pid/vid.
* Fri Mar 27 2015 dimstar@opensuse.org
- Update to version 0.12:
  + Added libwacom_stylus_has_wheel() for relative wheel detection.
  + Added libwacom_stylus_get_axes() for a list of supported axes.
  + New devices:
  - Cintiq 27QHD, Cintiq 27QHD Touch.
  - DTU-1031X.
  - Intuos Pen Medium.
  + Reworked udev rules:
  - be more restrictive when to set ID_INPUT_TOUCHPAD.
  - unset ID_INPUT_JOYSTICK on tablet devices.
  - tag the Pad device as ID_INPUT_TABLET_PAD.
* Wed Jan 28 2015 zaitor@opensuse.org
- Update to version 0.11:
  + Better detection of wireless tablets on kernels 3.18.
  + New devices: Cintiq Companion.
* Sat Aug 23 2014 dimstar@opensuse.org
- Update to version 0.10:
  + Fixed bus detection of Bluetooth tablets on kernels 3.14 and
    later.
  + New devices: ISDV4 0x12C, 116, 4004, 5000, 5002.
* Sat Mar  8 2014 dimstar@opensuse.org
- Update to version 0.9:
  + Add support for TouchSwitch keyword.
  + New devices:
  - Intuos series.
  - Pen&Touch (2nd gen).
  - DTU-1031.
  - Cintiq Companion Hybri.
* Thu Oct 10 2013 dimstar@opensuse.org
- Update to version 0.8 (bnc#845267):
  + New devices:
  - Cintiq 13HD, 22HD touch.
  - DTH-2242, DTU-1931.
  - ISDv4 EC, ED, 10F.
  - Intuos Pro.
* Tue Apr 16 2013 dimstar@opensuse.org
- Update to version 0.7.1:
  + New devices: ISDv4 10d.
  + Better checks to prevent bad databases.
* Tue Jan  8 2013 dimstar@opensuse.org
- Update to version 0.7:
  + New devices:
  - Cintiq 22HD, 24HD touch,
  - ISDv4 E5, 100, 101
  + Support for SVG layouts of the tablets
  + New APIs for:
  - list status LEDs
  - list integration flags (differ between builtin and
    screen-tablets)
* Fri Nov  9 2012 dimstar@opensuse.org
- Update to version 0.6.1:
  + More/corrected metadata for:
  - Cintiq 22HD, 24HD, 24HD touch.
  - DTI 520.
  - ISDv4 E5, 100, 101.
* Sat Jul 14 2012 zaitor@opensuse.org
- Update to version 0.6:
  + More metadata for:
  - NTrig tablet PC
  - ISDv4 0x93, 0x90, 0xED, 0xEF
  - Bamboo Pen, Fun, Craft, Touch
  + Support for debugging with uinput devices.
* Mon May 14 2012 vuntz@opensuse.org
- Update to version 0.5:
  + Add support for multiple match statements
  + Add support for bluetotooth devices
  + Add libwacom-list-local-devices helper tool
  + Add list-devices helper tool
  + Rename udev generation tool to generate-udev-rules
  + More metadata description updates
- Create a tools subpackage for the new libwacom-list-local-devices
  helper tool.
* Tue Mar 27 2012 vuntz@opensuse.org
- Update to version 0.4:
  + More metadata for:
  - Intuos4 WL
  - Bamboo One
  - Intuos5 series
  + Don't fail to create a WacomDevice for Touch devices
  + Add API to access all items in the database
  + Add helper tool to generate udev rules from the database
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 0.3:
  + Loads of new and updated tablet definition files
  + Add and correct information about styli
  + Update wacom.example with loads of documentation about adding
    new tablet definitions
  + Handle Puck device type
  + Support enumerating touchstrips, touchrings and buttons
  + Get device name from the kernel for generic tablets
  + Add support for the WACf004 serial tablet
  + Build fixes (exported symbols, soname)
- Remove xz BuildRequires now that it comes for free in the build
  system.
- Rename libwacom0 subpackage to libwacom2, following upstream
  soversion change.
* Tue Jan 17 2012 vuntz@opensuse.org
- Update to version 0.2:
  + Don't add devices that lack DeviceMatch
  + Get whether a device is builtin from udev
  + Fix definitions for Reversible property
  + Add definition for Cintiq 21UX2
  + Add test for serial devices
  + Fix Intuos4 styli's number of buttons
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Thu Jan  5 2012 vuntz@opensuse.org
- Initial package (version 0.1).
